pub struct Formatter<'c> { /* private fields */ }Expand description
Formats messages of one catalog.
Implementations
Sourceimpl<'c> Formatter<'c>
impl<'c> Formatter<'c>
Sourcepub const fn new(
catalog: &'c Catalog,
registry: &'c Registry,
cx: &'c FormatContext,
) -> Self
pub const fn new( catalog: &'c Catalog, registry: &'c Registry, cx: &'c FormatContext, ) -> Self
A formatter over catalog, with the handlers of registry.
Sourcepub fn simple(&self, id: MsgId) -> Option<&'c str>
pub fn simple(&self, id: MsgId) -> Option<&'c str>
The text of a simple message whose text is valid: no evaluator, no
allocation. None for any other message (use Formatter::write).
Sourcepub fn write(
&self,
id: MsgId,
args: &[Arg<'_>],
out: &mut dyn Sink,
errs: &mut dyn ErrorSink,
)
pub fn write( &self, id: MsgId, args: &[Arg<'_>], out: &mut dyn Sink, errs: &mut dyn ErrorSink, )
Formats message id with positional args into out.
Sourcepub fn parts(
&self,
id: MsgId,
args: &[Arg<'_>],
out: &mut dyn PartSink,
errs: &mut dyn ErrorSink,
)
pub fn parts( &self, id: MsgId, args: &[Arg<'_>], out: &mut dyn PartSink, errs: &mut dyn ErrorSink, )
Formats message id with positional args to parts.