pub struct Operands {
pub i: u64,
pub f: u64,
pub t: u64,
pub v: u32,
pub w: u32,
pub e: u32,
}Expand description
The UTS #35 operands of a non-negative decimal (Part 3 5.1.1): the
formatter’s side of the contract of plans/02-catalog-format.md 4.1.
n is integral iff t == 0, and then equals i.
Fields
i: u64Integer digits.
f: u64Visible fraction digits, with trailing zeros.
t: u64Visible fraction digits, without trailing zeros.
v: u32The number of visible fraction digits, with trailing zeros.
w: u32The number of visible fraction digits, without trailing zeros.
e: u32The compact decimal exponent (c, e); 0 from MF2’s :number.
Implementations