Formatter

Struct Formatter 

pub struct Formatter<'c> { /* private fields */ }
Formats messages of one catalog.

Implementations

Source

impl<'c> Formatter<'c>

pub const fn new( catalog: &'c Catalog, registry: &'c Registry, cx: &'c FormatContext, ) -> Self

A formatter over catalog, with the handlers of registry.

pub fn catalog(&self) -> &'c Catalog

The catalog.

pub fn simple(&self, id: MsgId) -> Option<&'c str>

The text of a simple message whose text is valid: no evaluator, no allocation. None for any other message (use Formatter::write).

pub fn write( &self, id: MsgId, args: &[Arg<'_>], out: &mut dyn Sink, errs: &mut dyn ErrorSink, )

Formats message id with positional args into out.

pub fn parts( &self, id: MsgId, args: &[Arg<'_>], out: &mut dyn PartSink, errs: &mut dyn ErrorSink, )

Formats message id with positional args to parts.

pub fn write_named( &self, id: MsgId, args: &[(&str, Arg<'_>)], out: &mut dyn Sink, errs: &mut dyn ErrorSink, )

Formats message id with named args: each slot takes the argument whose NFC name equals the slot’s name in NAMES.

pub fn parts_named( &self, id: MsgId, args: &[(&str, Arg<'_>)], out: &mut dyn PartSink, errs: &mut dyn ErrorSink, )

Formats message id with named args to parts.