Operands

Struct Operands 

pub struct Operands {
    pub i: u64,
    pub f: u64,
    pub t: u64,
    pub v: u32,
    pub w: u32,
    pub e: u32,
}
The UTS #35 operands of a non-negative decimal (Part 3 5.1.1): the formatter’s side of the contract of plans/02-catalog-format.md 4.1. n is integral iff t == 0, and then equals i.

Fields

i: u64

Integer digits.

f: u64

Visible fraction digits, with trailing zeros.

t: u64

Visible fraction digits, without trailing zeros.

v: u32

The number of visible fraction digits, with trailing zeros.

w: u32

The number of visible fraction digits, without trailing zeros.

e: u32

The compact decimal exponent (c, e); 0 from MF2’s :number.

Implementations

Source

impl Operands

pub fn parse(s: &str) -> Option<Operands>

The operands of a CLDR sample or an ASCII decimal: -? digit+ ('.' digit+)? ([ce] digit+)?. The exponent moves the decimal point right and keeps visible trailing zeros (1.20050c3 is 1200.50, e = 3). None if s does not match.